Python API Developer Guides
###########################

This page contains older tutorials and guides for using individual classes within C-Star to manually construct and run simulations and blueprints.
This is no longer the primary user interface, but the content may still be useful for developers.

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   Building a Simulation and exporting it as a blueprint <tutorials/1_building_a_simulation_and_exporting_it_as_a_blueprint>
   Importing and running a Simulation from a blueprint <tutorials/2_importing_and_running_a_simulation_from_a_blueprint>
   Restarting and continuing a Simulation <tutorials/3_restarting_and_continuing_a_simulation>

.. toctree::
   :maxdepth: 1
   :caption: How-to Guides

   Working with the AdditionalCode class <howto_guides/1_working_with_additionalcode>
   Working with the InputDataset class <howto_guides/2_working_with_inputdatasets>
   Working with the ExternalCodeBase class <howto_guides/3_working_with_externalcodebases>
   Tracking runs executed locally <howto_guides/4_running_on_personal_computers>
   Tracking runs executed as jobs on HPC systems <howto_guides/5_handling_jobs_on_hpc_systems>